# This empty file makes the zope namespace package work.
# It is the only file included in the 'zope' conda package.
# Conda packages which use the zope namespace do not include
# this file, but depend on the 'zope' conda package instead.
